TableRepo
=========

.. currentmodule:: parquetranger

.. autoclass:: TableRepo
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~TableRepo.dfs
      ~TableRepo.full_metadata
      ~TableRepo.full_path
      ~TableRepo.n_files
      ~TableRepo.paths

   .. rubric:: Methods Summary

   .. autosummary::

      ~TableRepo.batch_extend
      ~TableRepo.env_ctx
      ~TableRepo.extend
      ~TableRepo.get_full_ddf
      ~TableRepo.get_full_df
      ~TableRepo.map_partitions
      ~TableRepo.purge
      ~TableRepo.replace_all
      ~TableRepo.replace_groups
      ~TableRepo.replace_records
      ~TableRepo.set_env
      ~TableRepo.set_env_to_default

   .. rubric:: Attributes Documentation

   .. autoattribute:: dfs
   .. autoattribute:: full_metadata
   .. autoattribute:: full_path
   .. autoattribute:: n_files
   .. autoattribute:: paths

   .. rubric:: Methods Documentation

   .. automethod:: batch_extend
   .. automethod:: env_ctx
   .. automethod:: extend
   .. automethod:: get_full_ddf
   .. automethod:: get_full_df
   .. automethod:: map_partitions
   .. automethod:: purge
   .. automethod:: replace_all
   .. automethod:: replace_groups
   .. automethod:: replace_records
   .. automethod:: set_env
   .. automethod:: set_env_to_default
